@@ -17,6 +17,8 @@ i.rho <- sp <- qu.mag <- n.sel <- y1.y2 <- y1.cy2 <- cy1.y2 <- cy1.cy2 <- cy <-
 end <- X3.d2 <- X4.d2 <- X5.d2 <- X6.d2 <- X7.d2 <- X8.d2 <- l.sp3 <- l.sp4 <- l.sp5 <- l.sp6 <- l.sp7 <- l.sp8 <- i.rho <- 0
 gam1 <- gam2 <- gam3 <- gam4 <- gam5 <- gam6 <- gam7 <- gam8 <- gamlss2 <- dof.st <- NULL
 gamlss2 <- NULL
+Sl.sf <- NULL
+sp.method <- "perf"
   
 sp1 <- sp2 <- c.gam2 <- X2s <- X3s <- NULL
 sp3 <- gp3 <-   gam3 <- X3         <- NULL  
@@ -37,10 +39,10 @@ opc  <- c("N", "C0", "C90", "C180", "C270",
 scc  <- c("C0" , "C180", "J0" , "J180", "G0" , "G180", BivD2)
 sccn <- c("C90", "C270", "J90", "J270", "G90", "G270")
 mb   <- c("B", "BSS", "BPO", "BPO0")
-m2   <- c("N", "N2", "GU", "rGU", "LO", "LN", "WEI", "iG", "GA", "BE", "FISK","GP")
-m3   <- c("DAGUM", "SM")
+m2   <- c("N", "GU", "rGU", "LO", "LN", "WEI", "iG", "GA", "BE", "FISK","GP","GPII","GPo")
+m3   <- c("DAGUM", "SM","TW")
 m1d  <- c("PO", "ZTP") 
-m2d  <- c("NBI", "NBII", "NBIa", "NBIIa", "PIG","DGP") 
+m2d  <- c("NBI", "NBII", "PIG","DGP","DGPII") 
 bl   <- c("probit", "logit", "cloglog") # , "cauchit")   
 M    <- list(m1d = m1d, m2 = m2, m2d = m2d, m3 = m3, BivD = BivD, 
              opc = opc, extra.regI = extra.regI, margins = margins, bl = bl, intf = intf,
@@ -253,7 +255,7 @@ names(i.rho) <- "theta.star"
 if(margins[1] %in% bl && margins[2] %in% c(m2)){
 
 start.snR <- startsn(margins[2], y2)    
-log.sig2  <- start.snR$log.sig2.1; names(log.sig2) <- "sigma2.star"
+log.sig2  <- start.snR$log.sig2.1; names(log.sig2) <- "sigma.star"
 
 #if(margins[2] %in% c(m3    )){ log.nu <- start.snR$log.nu.1; names(log.nu) <- "nu.star"}       
 if(margins[2] %in% c(m2))  start.v <- c(c1.ti, gam1$coefficients, gam2$coefficients, log.sig2,         i.rho)        
@@ -364,7 +366,7 @@ lsgam7 <- length(gam7$smooth)
 lsgam8 <- length(gam8$smooth)
 
 VC <- list(lsgam1 = lsgam1, robust = FALSE, sel = sel, sel.p = sel.p, sel.m = sel.m, sel.mm = sel.mm, sel.pm = sel.pm, c1 = c1, D11 = D11, D12 = D12, 
-           lsgam2 = lsgam2,
+           lsgam2 = lsgam2, Sl.sf = Sl.sf, sp.method = sp.method,
            lsgam3 = lsgam3,
            lsgam4 = lsgam4,
            lsgam5 = lsgam5,
@@ -546,7 +548,7 @@ gam5$call$data <- gam6$call$data <- gam7$call$data <- gam8$call$data <- cl$data
 
 if(!(Model == "B" && !(margins[2] %in% bl) && end == 2)) {dataset <- NULL; rm(data)} else {attr(data, "terms") <- NULL; dataset <- data; rm(data)} 
 
-L <- list(fit = CopulaCLMFit$fit, dataset = dataset, formula = formula, CopulaCLMFit = CopulaCLMFit,
+L <- list(fit = CopulaCLMFit$fit, dataset = dataset, formula = formula, CopulaCLMFit = CopulaCLMFit, robust = FALSE,
           gam1 = gam1, gam2 = gam2, gam3 = gam3, gam4 = gam4, gam5 = gam5, gam6 = gam6,
           gam7 = gam7, gam8 = gam8,
           coefficients = CopulaCLMFit$fit$argument, coef.t = NULL, iterlimsp = iterlimsp,
@@ -588,7 +590,7 @@ L <- list(fit = CopulaCLMFit$fit, dataset = dataset, formula = formula, CopulaCL
           logLik = CopulaCLMFit.p$logLik,
           nC = nC, hess = hess,
           respvec = respvec, inde = inde,
-          qu.mag = qu.mag,
+          qu.mag = qu.mag, sigma = CopulaCLMFit.p$sigma, sigma.a = CopulaCLMFit.p$sigma.a,
           sigma2 = CopulaCLMFit.p$sigma2, sigma2.a = CopulaCLMFit.p$sigma2.a,
           nu = CopulaCLMFit.p$nu, nu.a = CopulaCLMFit.p$nu.a, Vb.t = CopulaCLMFit.p$Vb.t,
           gp1 = gp1, gp2 = gp2, gp3 = gp3, gp4 = gp4, gp5 = gp5, gp6 = gp6, gp7 = gp7, gp8 = gp8, 
@@ -612,7 +614,7 @@ L$Cop2      <- CopulaCLMFit$fit$Cop2
 }
 
 
-class(L) <- c("SemiParBIV","CopulaCLM", "gjrm")
+class(L) <- c("CopulaCLM", "SemiParBIV", "gjrm")
 
 L
 
