@@ -17,9 +17,9 @@ if(is.null(VC$X2)){VC$X2 <- VC$X3 <- matrix(1, n, 1); VC$X2.d2 <- VC$X3.d2 <- 1}
 
 if(is.null(VC$lB) && is.null(VC$uB)){
 
-if( margin %in% c("N","N2","GU","rGU","LO","LN") )                   { lB <- -Inf;      uB <- Inf}
-if( margin %in% c("WEI","iG","GA","DAGUM","SM","FISK","GP")  )      { lB <- 0.0000001; uB <- Inf}
-if( margin %in% c("BE")  )                                           { lB <- 0.0000001; uB <- 0.9999999}
+if( margin %in% c("N","GU","rGU","LO","LN") )                   { lB <- -Inf;      uB <- Inf}
+if( margin %in% c("WEI","iG","GA","DAGUM","SM","FISK","GP","GPII","GPo","TW")  )      { lB <- sqrt(.Machine$double.eps); uB <- Inf} # tw should be zero here?
+if( margin %in% c("BE")  )                                           { lB <- sqrt(.Machine$double.eps); uB <- 0.9999999}
 
 }else{lB <- VC$lB; uB <- VC$uB}
 
@@ -36,7 +36,7 @@ for(i in 1:n){
   sigma2    <- esp.tr(X2%*%params[(1+VC$X1.d2):(VC$X1.d2+VC$X2.d2)], margin)$vrb
   sigma2.st <- X2%*%params[(1+VC$X1.d2):(VC$X1.d2+VC$X2.d2)]
   
-  if( margin %in% c("DAGUM","SM") ){
+  if( margin %in% c("DAGUM","SM","TW") ){
   nu.st <- X3%*%params[(1+VC$X1.d2+VC$X2.d2):(VC$X1.d2+VC$X2.d2+VC$X3.d2)]
   nu    <- enu.tr(X3%*%params[(1+VC$X1.d2+VC$X2.d2):(VC$X1.d2+VC$X2.d2+VC$X3.d2)], margin)$vrb
   }
