@@ -1,8 +1,8 @@
 pp <- function(x){
 
    cont1par <- c("PO","ZTP","probit","logit","cloglog","GEVlink")  
-   cont2par <- c("N","N2","GU","rGU","LO","LN","WEI","GO","iG","GA","GA2","GAi","BE","FISK","NBI", "NBII","NBIa", "NBIIa","PIG","GP","DGP")  
-   cont3par <- c("DAGUM","SM","DEL","SICHEL","GGA")   
+   cont2par <- c("N","N2","GU","rGU","LO","LN","WEI","GO","iG","GA","GA2","GAi","BE","FISK","NBI", "NBII","NBIa", "NBIIa","PIG","GP","GPII","GPo","DGP","DGPII")  
+   cont3par <- c("DAGUM","SM","DEL","SICHEL","GGA","TW")   
 
 if(x$univar.gamlss == TRUE) x$BivD <- "N" 
 
@@ -47,7 +47,10 @@ if(x$univar.gamlss == TRUE) x$BivD <- "N"
   
   # if(x$BivD=="N" && x$Model=="BPO0") cop <- "Independent"   
     
-  mml <- c("LN","WEI","GO","iG","GA","GA2","GGA","DAGUM","SM","FISK","NBI","NBII","NBIa","NBIIa","PIG","PO","ZTP","GP","DGP")  
+  mml <- c("LN","WEI","GO","iG","GA","GA2","GGA","DAGUM","SM","FISK","NBI","NBII","NBIa","NBIIa","PIG","PO","ZTP","GP","GPII","GPo","DGP","DGPII","TW")  
+  
+  
+  
     
   if(x$margins[1] %in% c("N","N2","GU","rGU","LO","GAi") )  m1l <- "identity"
   if(x$margins[2] %in% c("N","N2","GU","rGU","LO","GAi") )  m2l <- "identity"
@@ -58,6 +61,12 @@ if(x$univar.gamlss == TRUE) x$BivD <- "N"
   if(x$margins[1] %in% c("GP","DGP") )                    m1l <- "identity"
   if(x$margins[2] %in% c("GP","DGP") )                    m2l <- "identity"  
   
+  if(x$margins[1] %in% c("DGPII") )                       m1l <- "sqrt"
+  if(x$margins[2] %in% c("DGPII") )                       m2l <- "sqrt"  
+  
+  if(x$margins[1] %in% c("GPII","GPo") )                       m1l <- "log(\u00B7 + 0.5)"
+  if(x$margins[2] %in% c("GPII","GPo") )                       m2l <- "log(\u00B7 + 0.5)"     
+  
   if(x$margins[1] %in% c("BE") )                            m1l <- "qlogis" 
   if(x$margins[2] %in% c("BE") )                            m2l <- "qlogis"   
  
