@@ -57,7 +57,7 @@ if(!is.null(x$tableP3) && !is.null(x$tableP4) && is.null(x$tableP5)  ){
 
 
   cat("\nEQUATION 3")
-  if(x$margins[2]!="BE") cat("\nLink function for sigma2:","log","\n") else cat("\nLink function for sigma2:","qlogis","\n")
+  if(x$margins[2]!="BE") cat("\nLink function for sigma:","log","\n") else cat("\nLink function for sigma:","qlogis","\n")
   cat("Formula: "); print(x$formula[[3]])
   cat("\n")
   cat("Parametric coefficients:\n")
@@ -92,7 +92,11 @@ if(!is.null(x$tableP3) && !is.null(x$tableP4) && !is.null(x$tableP5)  ){
 
 
   cat("\nEQUATION 3")
-  cat("\nLink function for sigma2:","log","\n") 
+  #cat("\nLink function for sigma:","log","\n") 
+  
+  if(!(x$margins[2] %in% c("TW"))) cat("\nLink function for sigma:","log","\n") else cat("\nLink function for sigma:","qlogis","\n")  
+
+  
   cat("Formula: "); print(x$formula[[3]])
   cat("\n")
   cat("Parametric coefficients:\n")
@@ -106,7 +110,7 @@ if(!is.null(x$tableP3) && !is.null(x$tableP4) && !is.null(x$tableP5)  ){
     }  
     
   cat("\nEQUATION 4")
-  if(x$margins[2] %in% c("DAGUM","SM")) cat("\nLink function for nu:","log","\n")  
+  if(x$margins[2] %in% c("DAGUM","SM","TW")) cat("\nLink function for nu:","log","\n")  
   cat("Formula: "); print(x$formula[[4]])
   cat("\n")
   cat("Parametric coefficients:\n")
@@ -324,7 +328,7 @@ if( x$margins[1] %in% cont2par && x$margins[2] %in% cont2par){
 
 
   cat("\nEQUATION 3")
-  if(x$margins[1] !="BE") cat("\nLink function for sigma2.1:","log","\n") else cat("\nLink function for sigma2.1:","qlogis","\n") 
+  if(x$margins[1] !="BE") cat("\nLink function for sigma.1:","log","\n") else cat("\nLink function for sigma.1:","qlogis","\n") 
   cat("Formula: "); print(x$formula[[3]]) 
   cat("\n")
     cat("Parametric coefficients:\n")
@@ -339,7 +343,7 @@ if( x$margins[1] %in% cont2par && x$margins[2] %in% cont2par){
     
      
   cat("\nEQUATION 4")
-  if(x$margins[2] !="BE") cat("\nLink function for sigma2.2:","log","\n") else cat("\nLink function for sigma2.2:","qlogis","\n")  
+  if(x$margins[2] !="BE") cat("\nLink function for sigma.2:","log","\n") else cat("\nLink function for sigma.2:","qlogis","\n")  
   cat("Formula: "); print(x$formula[[4]]) 
     cat("\n")
       cat("Parametric coefficients:\n")
@@ -394,7 +398,7 @@ if( x$margins[1] %in% cont2par && x$margins[2] %in% cont2par){
 
 
   cat("\nEQUATION 3")
-  cat("\nLink function for sigma2.1:","log","\n") 
+  cat("\nLink function for sigma.1:","log","\n") 
   cat("Formula: "); print(x$formula[[3]])  
     cat("\n")
       cat("Parametric coefficients:\n")
@@ -408,7 +412,7 @@ if( x$margins[1] %in% cont2par && x$margins[2] %in% cont2par){
       }
      
   cat("\nEQUATION 4")
-  cat("\nLink function for sigma2.2:","log","\n") 
+  cat("\nLink function for sigma.2:","log","\n") 
   cat("Formula: "); print(x$formula[[4]])  
       cat("\n")
         cat("Parametric coefficients:\n")
@@ -490,7 +494,7 @@ if( x$margins[1] %in% cont2par && x$margins[2] %in% cont2par){
 
 
   cat("\nEQUATION 3")
-  if(x$margins[1] !="BE") cat("\nLink function for sigma2.1:","log","\n") else cat("\nLink function for sigma2.1:","qlogis","\n")
+  if(x$margins[1] !="BE") cat("\nLink function for sigma.1:","log","\n") else cat("\nLink function for sigma.1:","qlogis","\n")
   cat("Formula: "); print(x$formula[[3]])  
     cat("\n")
       cat("Parametric coefficients:\n")
@@ -504,7 +508,7 @@ if( x$margins[1] %in% cont2par && x$margins[2] %in% cont2par){
       }
      
   cat("\nEQUATION 4")
-  cat("\nLink function for sigma2.2:","log","\n") 
+  cat("\nLink function for sigma.2:","log","\n") 
   cat("Formula: "); print(x$formula[[4]])  
       cat("\n")
         cat("Parametric coefficients:\n")
@@ -578,7 +582,7 @@ if( x$margins[1] %in% cont2par && x$margins[2] %in% cont2par){
 
 
   cat("\nEQUATION 3")
-  cat("\nLink function for sigma2.1:","log","\n") 
+  cat("\nLink function for sigma.1:","log","\n") 
   cat("Formula: "); print(x$formula[[3]])  
     cat("\n")
       cat("Parametric coefficients:\n")
@@ -592,7 +596,7 @@ if( x$margins[1] %in% cont2par && x$margins[2] %in% cont2par){
       }
      
   cat("\nEQUATION 4")
-  if(x$margins[2] !="BE") cat("\nLink function for sigma2.2:","log","\n") else cat("\nLink function for sigma2.2:","qlogis","\n")
+  if(x$margins[2] !="BE") cat("\nLink function for sigma.2:","log","\n") else cat("\nLink function for sigma.2:","qlogis","\n")
   cat("Formula: "); print(x$formula[[4]])  
       cat("\n")
         cat("Parametric coefficients:\n")
@@ -669,7 +673,7 @@ if( x$margins[1] %in% cont2par && x$margins[2] %in% cont1par && x$surv.flex == T
 
 
   cat("\nEQUATION 3")
-  if(x$margins[1] !="BE") cat("\nLink function for sigma2.1:","log","\n") else cat("\nLink function for sigma2.1:","qlogis","\n") 
+  if(!(x$margins[1] %in% c("BE","TW"))) cat("\nLink function for sigma.1:","log","\n") else cat("\nLink function for sigma.1:","qlogis","\n") 
   cat("Formula: "); print(x$formula[[3]]) 
   cat("\n")
     cat("Parametric coefficients:\n")
@@ -711,7 +715,7 @@ if( x$margins[1] %in% cont3par && x$margins[2] %in% cont1par && x$surv.flex == T
 
 
   cat("\nEQUATION 3")
-  cat("\nLink function for sigma2.1:","log","\n") 
+  cat("\nLink function for sigma.1:","log","\n") 
   cat("Formula: "); print(x$formula[[3]])  
     cat("\n")
       cat("Parametric coefficients:\n")
@@ -766,7 +770,7 @@ if( x$margins[1] %in% cont2par && x$margins[2] %in% cont2par){
 
 
   cat("\nEQUATION 3")
-  if(x$margins[1] !="BE") cat("\nLink function for sigma2.1:","log","\n") else cat("\nLink function for sigma2.1:","qlogis","\n") 
+  if(x$margins[1] !="BE") cat("\nLink function for sigma.1:","log","\n") else cat("\nLink function for sigma.1:","qlogis","\n") 
   cat("Formula: "); print(x$formula[[3]]) 
   cat("\n")
     cat("Parametric coefficients:\n")
@@ -781,7 +785,7 @@ if( x$margins[1] %in% cont2par && x$margins[2] %in% cont2par){
     
      
   cat("\nEQUATION 4")
-  if(x$margins[2] !="BE") cat("\nLink function for sigma2.2:","log","\n") else cat("\nLink function for sigma2.2:","qlogis","\n")  
+  if(x$margins[2] !="BE") cat("\nLink function for sigma.2:","log","\n") else cat("\nLink function for sigma.2:","qlogis","\n")  
   cat("Formula: "); print(x$formula[[4]]) 
     cat("\n")
       cat("Parametric coefficients:\n")
@@ -849,7 +853,7 @@ if( x$margins[1] %in% cont2par && x$margins[2] %in% cont2par){
 
  
   cat("\nEQUATION 3")
-  if(x$margins[2] !="BE") cat("\nLink function for sigma2.2:","log","\n") else cat("\nLink function for sigma2.2:","qlogis","\n")  
+  if(x$margins[2] !="BE") cat("\nLink function for sigma.2:","log","\n") else cat("\nLink function for sigma.2:","qlogis","\n")  
   cat("Formula: "); print(x$formula[[3]]) 
     cat("\n")
       cat("Parametric coefficients:\n")
@@ -895,7 +899,7 @@ if( x$margins[1] %in% cont2par && x$margins[2] %in% cont2par){
 
 
   cat("\nEQUATION 3")
-  cat("\nLink function for sigma2.2:","log","\n") 
+  cat("\nLink function for sigma.2:","log","\n") 
   cat("Formula: "); print(x$formula[[3]])  
       cat("\n")
         cat("Parametric coefficients:\n")
@@ -952,7 +956,7 @@ if( x$margins[1] %in% cont2par && x$margins[2] %in% cont2par){
 
 
   cat("\nEQUATION 3")
-  cat("\nLink function for sigma2.1:","log","\n") 
+  cat("\nLink function for sigma.1:","log","\n") 
   cat("Formula: "); print(x$formula[[3]])  
     cat("\n")
       cat("Parametric coefficients:\n")
@@ -966,7 +970,7 @@ if( x$margins[1] %in% cont2par && x$margins[2] %in% cont2par){
       }
      
   cat("\nEQUATION 4")
-  cat("\nLink function for sigma2.2:","log","\n") 
+  cat("\nLink function for sigma.2:","log","\n") 
   cat("Formula: "); print(x$formula[[4]])  
       cat("\n")
         cat("Parametric coefficients:\n")
@@ -1037,7 +1041,7 @@ if( x$margins[1] %in% cont2par && x$margins[2] %in% cont2par){
 
 
   cat("\nEQUATION 3")
-  if(x$margins[1] !="BE") cat("\nLink function for sigma2.1:","log","\n") else cat("\nLink function for sigma2.1:","qlogis","\n")
+  if(x$margins[1] !="BE") cat("\nLink function for sigma.1:","log","\n") else cat("\nLink function for sigma.1:","qlogis","\n")
   cat("Formula: "); print(x$formula[[3]])  
     cat("\n")
       cat("Parametric coefficients:\n")
@@ -1051,7 +1055,7 @@ if( x$margins[1] %in% cont2par && x$margins[2] %in% cont2par){
       }
      
   cat("\nEQUATION 4")
-  cat("\nLink function for sigma2.2:","log","\n") 
+  cat("\nLink function for sigma.2:","log","\n") 
   cat("Formula: "); print(x$formula[[4]])  
       cat("\n")
         cat("Parametric coefficients:\n")
@@ -1110,7 +1114,7 @@ if( x$margins[1] %in% cont2par && x$margins[2] %in% cont2par){
 
 
   cat("\nEQUATION 3")
-  cat("\nLink function for sigma2.1:","log","\n") 
+  cat("\nLink function for sigma.1:","log","\n") 
   cat("Formula: "); print(x$formula[[3]])  
     cat("\n")
       cat("Parametric coefficients:\n")
@@ -1124,7 +1128,7 @@ if( x$margins[1] %in% cont2par && x$margins[2] %in% cont2par){
       }
      
   cat("\nEQUATION 4")
-  if(x$margins[2] !="BE") cat("\nLink function for sigma2.2:","log","\n") else cat("\nLink function for sigma2.2:","qlogis","\n")
+  if(x$margins[2] !="BE") cat("\nLink function for sigma.2:","log","\n") else cat("\nLink function for sigma.2:","qlogis","\n")
   cat("Formula: "); print(x$formula[[4]])  
       cat("\n")
         cat("Parametric coefficients:\n")
@@ -1230,13 +1234,13 @@ if(type == "gamls"){
   
   cat("\nEQUATION 2")
   
-  if(x$margins[1] !="BE") cat("\nLink function for sigma2:","log","\n") else cat("\nLink function for sigma2:","qlogis","\n") 
+  if( !(x$margins[1] %in%c("BE","TW")) ) cat("\nLink function for sigma:","log","\n") else cat("\nLink function for sigma:","qlogis","\n") 
   
-  #if(x$margins[1] !="BE" && !(x$margins[1] %in% c("GP","DGP"))) cat("\nLink function for sigma2:","log","\n")
+  #if(x$margins[1] !="BE" && !(x$margins[1] %in% c("GP","DGP","DGPII"))) cat("\nLink function for sigma:","log","\n")
   
-  #if(x$margins[1] =="BE") cat("\nLink function for sigma2:","qlogis","\n") 
+  #if(x$margins[1] =="BE") cat("\nLink function for sigma:","qlogis","\n") 
   
-  #if(x$margins[1] %in% c("GP","DGP")) cat("\nLink function for sigma2:","identity","\n")   
+  #if(x$margins[1] %in% c("GP","DGP","DGPII")) cat("\nLink function for sigma:","identity","\n")   
   
 
   cat("Formula: "); print(x$formula[[2]]) 
@@ -1258,7 +1262,16 @@ if(type == "gamls"){
 if( x$margins[1] %in% cont3par){
 
   cat("\nEQUATION 2")
-  cat("\nLink function for sigma2:","log","\n") 
+  
+  
+  #cat("\nLink function for sigma:","log","\n") 
+  
+  if( !(x$margins[1] %in%c("BE","TW")) ) cat("\nLink function for sigma:","log","\n") else cat("\nLink function for sigma:","qlogis","\n") 
+
+  
+  
+  
+  
   cat("Formula: "); print(x$formula[[2]])  
     cat("\n")
       cat("Parametric coefficients:\n")
@@ -1368,7 +1381,7 @@ if(!is.null(x$tableP3) && !is.null(x$tableP4) && is.null(x$tableP5)  ){
 
 
   cat("\nEQUATION 3")
-  if(x$margins[2]!="BE") cat("\nLink function for sigma2:","log","\n") else cat("\nLink function for sigma2:","qlogis","\n")
+  if(!(x$margins[2]%in%c("BE","TW"))) cat("\nLink function for sigma:","log","\n") else cat("\nLink function for sigma:","qlogis","\n")
   cat("Formula: "); print(x$formula[[3]])
   cat("\n")
   cat("Parametric coefficients:\n")
@@ -1403,7 +1416,11 @@ if(!is.null(x$tableP3) && !is.null(x$tableP4) && !is.null(x$tableP5)  ){
 
 
   cat("\nEQUATION 3")
-  cat("\nLink function for sigma2:","log","\n") 
+ # cat("\nLink function for sigma:","log","\n") 
+  
+    if(!(x$margins[2] %in% c("TW"))) cat("\nLink function for sigma:","log","\n") else cat("\nLink function for sigma:","qlogis","\n")  
+
+  
   cat("Formula: "); print(x$formula[[3]])
   cat("\n")
   cat("Parametric coefficients:\n")
@@ -1417,7 +1434,7 @@ if(!is.null(x$tableP3) && !is.null(x$tableP4) && !is.null(x$tableP5)  ){
     }  
     
   cat("\nEQUATION 4")
-  if(x$margins[2] %in% c("DAGUM","SM")) cat("\nLink function for nu:","log","\n")  
+  if(x$margins[2] %in% c("DAGUM","SM","TW")) cat("\nLink function for nu:","log","\n")  
   cat("Formula: "); print(x$formula[[4]])
   cat("\n")
   cat("Parametric coefficients:\n")
