@@ -5,19 +5,21 @@ resp.check <- function(y, margin = "N",
                            intervals = FALSE, n.sim = 100, prob.lev = 0.05, 
                            i.f = FALSE, ...){
 
-m2 <- c("N","N2","GU","rGU","LO","LN","WEI","iG","GA","GAi","BE","FISK","GP")
-m3 <- c("DAGUM","SM")
+m2 <- c("N","GU","rGU","LO","LN","WEI","iG","GA","GAi","BE","FISK","GP","GPII","GPo")
+m3 <- c("DAGUM","SM","TW")
 nu <- NULL
 m1d  <- c("PO","ZTP")
-m2d  <- c("NBI", "NBII","NBIa", "NBIIa","PIG","DGP")
+m2d  <- c("NBI", "NBII","NBIa", "NBIIa","PIG","DGP","DGPII")
 m3d  <- c("DEL","SICHEL")
 
 y1m <- NA
 y <- as.numeric( na.omit(y) )
 
-if(!(margin %in% c(m2,m3,m1d,m2d)) ) stop("Error in margin value. It should be one of:\nN, N2, GU, rGU, LO, LN, WEI, iG, GA, DAGUM, SM, BE, FISK, NBI, NBII, PIG, PO, ZTP, GP, DGP.") 
+if(!(margin %in% c(m2,m3,m1d,m2d)) ) stop("Error in margin value. It should be one of:\nN, GU, rGU, LO, LN, WEI, iG, GA, DAGUM, TW, SM, BE, FISK, NBI, NBII, PIG, PO, ZTP, GP, GPII, GPo, DGP, DGPII.") 
+
+if(margin %in% c("LN","WEI","iG","GA","GAi","DAGUM","SM","FISK") && min(y, na.rm = TRUE) <= 0) stop("The response must be positive.")
+if(margin %in% c("TW") && min(y, na.rm = TRUE) < 0) stop("The response must be > = 0.")
 
-if(margin %in% c("LN","WEI","iG","GA","GAi","DAGUM","SM","FISK","GP") && min(y, na.rm = TRUE) <= 0) stop("The response must be positive.")
 if(margin %in% c("BE") && (min(y, na.rm = TRUE) <= 0 || max(y, na.rm = TRUE) >= 1) ) stop("The response must be in the interval (0,1).")
    
     if(margin %in% c(m1d,m2d,m3d) && min(y, na.rm = TRUE) < 0) stop("The response must be positive.")
@@ -63,34 +65,48 @@ if( margin %in% c("rGU") )              st.v <- c( mean(y) - 0.57722*sqrt(var(y)
 if( margin %in% c("WEI") )              st.v <- c( log( mean( exp(log(y) + 0.5772/(1.283/sqrt(var(log(y))))) )  ) , log( ( 1.283/sqrt(var(log(y))) )^2 ) ) 
 if( margin %in% c("GA") )               st.v <- c( log(mean((y + mean(y))/2)), log(var(y)/mean(y)^2)  ) # log( 1^2 )             
 if( margin %in% c("GAi") )              st.v <- c( mean((y + mean(y))/2), log(var(y)/mean(y)^2)  ) # log( 1^2 )
+if( margin %in% c("TW") )               st.v <- coef(gam(list(y ~ 1, ~ 1, ~ 1), family = twlss()))
 
 
-#if( margin %in% c("GP","DGP") )       st.v <- c( log(10) ,   0.0025 )  
-# or
-#if( margin %in% c("GP","DGP") )       st.v <- c( 0.05, log(100)  )  
-
-
-if( margin %in% c("GP","DGP") )       st.v <- c( 0.05, log( mean((y + mean(y))/2)^2  )  )             
 
 
+#if( margin %in% c("GP","DGP") )         st.v <- c( log(10) ,   0.0025 )  
+#if( margin %in% c("GP","DGP") )         st.v <- c( 0.05, log(100)  )  
 #if( margin %in% c("GA2") )              st.v <- c( mean(y)^2/var(y), log(mean(y)/var(y))  ) # log( 1^2 )
 #if( margin %in% c("GGA") )              st.v <- c( log(mean(y)), log(1), log(1) )
 
 
+
+if( margin %in% c("GP","GPII","GPo","DGP","DGPII") ){
+
+ est.ob <- try(  gpd.fit(y, threshold = 0, siglink = exp, show = FALSE), silent = TRUE) 
+ 
+ if(class(est.ob) == "try-error") est.ob <- try( gpd.fit(y, threshold = 0, siglink = exp, show = FALSE, siginit = mean(y + mean(y))/2, shinit = 0.0025), silent = TRUE)  
+ if(class(est.ob) == "try-error") st.v <- c( 0.0025, log( mean((y + mean(y))/2)  )  ) 
+ if(class(est.ob) != "try-error") st.v <- c( est.ob$mle[2], est.ob$mle[1]  ) 
+  
+ if( margin %in% c("GPo","GPII","DGPII") ) { if(st.v[1] < 0) st.v[1] <- 0.001  }
+
+ if( margin %in% c("GPII","GPo") ) st.v[1] <- log(st.v[1] + 0.5) 
+ if( margin %in% c("DGPII") )      st.v[1] <- sqrt(st.v[1])
+ 
+
+}                                                              
+
 if( margin %in% c("DAGUM","SM") )       st.v <- c( log(mean((y + mean(y))/2)), log(sqrt(2)), log(1) )   # log(0.01) #  log(sqrt(2))       # 0.1    
 if( margin %in% c("FISK") )             st.v <- c( log(mean((y + mean(y))/2)), log(sqrt(2)))    
 if( margin %in% c("BE") )               st.v <- c( qlogis(mean((y + mean(y))/2)), qlogis( var(y)/( mean(y)*(1-mean(y)) )  )  )              
 
 if( margin %in% c(m1d) )    names(st.v) <- c("mu.star")
-if( margin %in% c(m2,m2d) ) names(st.v) <- c("mu.star", "sigma2.star")
-if( margin %in% c(m3,m3d) ) names(st.v) <- c("mu.star", "sigma2.star", "nu.star")
+if( margin %in% c(m2,m2d) ) names(st.v) <- c("mu.star", "sigma.star")
+if( margin %in% c(m3,m3d) ) names(st.v) <- c("mu.star", "sigma.star", "nu.star")
 
 
 if(print.par == TRUE && os == TRUE){ 
 
 if( margin %in% c(m1d) )    names(st.v) <- c("mu")
-if( margin %in% c(m2,m2d) ) names(st.v) <- c("mu", "sigma2")
-if( margin %in% c(m3,m3d) ) names(st.v) <- c("mu", "sigma2", "nu")
+if( margin %in% c(m2,m2d) ) names(st.v) <- c("mu", "sigma")
+if( margin %in% c(m3,m3d) ) names(st.v) <- c("mu", "sigma", "nu")
 
 }
 
@@ -112,7 +128,7 @@ if(plots == TRUE){ ##
 if(margin == "LN") y <- exp(y)
 
 
-    if(margin %in% c("ZTP","DGP")){
+    if(margin %in% c("ZTP","DGP","DGPII")){
      
     ly1 <- length(y)
     y1m <- list()
@@ -175,7 +191,7 @@ if(print.par == TRUE && os == FALSE && i.f == FALSE) print( univfit$argument )
 if(print.par == TRUE && os == TRUE && i.f == FALSE){         
          
 mu    <- eta.tr(univfit$argument[1], margin)
-mupos <- c("LN","WEI","iG","GA","DAGUM","SM","FISK",m1d,m2d,m3d)
+mupos <- c("LN","WEI","iG","GA","DAGUM","SM","TW","FISK",m1d,m2d,m3d)
 mub   <- c("BE")
 if(margin %in% mupos) mu <- exp(mu)
 if(margin %in% mub)   mu <- plogis(mu)
@@ -186,7 +202,7 @@ if(margin %in% m3)  nu <- esp.tr(univfit$argument[3], margin)$vrb
 if(margin %in% m3d) nu <- enu.tr(univfit$argument[3], margin)$vrb   
 
 
-if(!(margin %in% m1d)) print( c(mu) ) else print( c(mu,sigma,nu) )
+if(!(margin %in% m1d)) print( c(mu) ) else print( c(mu, sigma, nu) )
                  
 }
 
